@@ -1,4 +1,4 @@
-import datetime, operator
+import datetime, operator, time, urllib
 from stackweb import WebRequestManager
 from stackcore import *
 
@@ -44,28 +44,39 @@ class Answer(JSONModel):
 		self.votes = (self.up_vote_count, self.down_vote_count)
 		self.url = 'http://' + self.site.root_domain + '/questions/' + str(self.question_id) + '/' + str(self.id) + '#' + str(self.id)
 	
-	def _get_user(s,id):
-		s._owner = s.site.user(id)
-		return s._owner
-	def _set_user(s,ob):
-		s._owner = pb
-	def _get_quest(s,id):
-		s._question = s.site.question(id)
-		return s._question
-	def _set_quest(s,ob):
-		s._question = ob
+	def _get_user(self, id):
+		if self._owner is None:
+			self._owner = self.site.user(id)
+		return self._owner
 	
-	question = property(lambda self: self._question if self._question is not None else self._get_quest(self.question_id), _set_quest)
-	owner = property(lambda self: self._owner if self._owner is not None else self._get_user(self.owner_id), _set_user)
+	def _set_user(self, ob):
+		self._owner = ob
+	
+	def _get_quest(self, id):
+		if self._question is None:
+			self._question = self.site.question(id)
+		return self._question
 
+	def _set_quest(self, ob):
+		self._question = ob
+	
+	question = property(_get_quest, _set_quest)
+	owner = property(_get_user, _set_user)
+
+	def fetch_callback(self, _, site):
+		return site.answer(self.id)
+	
 	def __unicode__(self):
 		return u'Answer %d [%s]' % (self.id, self.title)
+	
 	def __str__(self):
 		return str(unicode(self))
+	
+	def __repr__(self):
+		return '<Answer %d @ %x>' % (self.id, id(self))
 
 class Question(JSONModel):
 	"""Describes a question on a StackExchange site."""
-
 	transfer = ('tags', 'favorite_count', 'up_vote_count', 'down_vote_count', 'view_count', 'score', 'community_owned', 'title', 'body')
 
 	def _extend(self, json, site):
@@ -85,7 +96,7 @@ class Question(JSONModel):
 		if hasattr(json, 'owner'):
 			self.owner_id = json.owner['user_id']
 	
-			owner_dict = json.owner
+			owner_dict = dict(json.owner)
 			owner_dict['id'] = self.owner_id
 			del owner_dict['user_id']
 			owner_dict['user_type'] = UserType.from_string(owner_dict['user_type'])
@@ -93,6 +104,18 @@ class Question(JSONModel):
 			self.owner = User.partial(lambda self: self.site.user(self.id), site, owner_dict)
 
 		self.url = 'http://' + self.site.root_domain + '/questions/' + str(self.id)
+	
+	def fetch_callback(self, _, site):
+		return site.question(self.id)
+
+	def linked(self):
+		return self.site.questions(linked_to=self.id)
+	
+	def related(self):
+		return self.site.questions(related_to=self.id)
+
+	def __repr__(self):
+		return "<Question '%s' @ %x>" % (self.title, id(self))
 
 class Comment(JSONModel):
 	"""Describes a comment to a question or answer on a StackExchange site."""
@@ -124,11 +147,16 @@ class Comment(JSONModel):
 				'email_hash': json.reply_to['email_hash']})
 		
 		self.post_type = PostType.from_string(json.post_type)
-	def get_post(self):
+
+	def _get_post(self):
 		if self.post_type == PostType.Question:
 			return self.site.question(self.post_id)
 		elif self.post_type == PostType.Answer:
 			return self.site.answer(self.post_id)
+		else:
+			return None
+	
+	post = property(_get_post)
 	
 	def __unicode__(self):
 		return u'Comment ' + str(self.id)
@@ -152,13 +180,69 @@ class PostRevision(JSONModel):
 			'email_hash': part['email_hash']
 		})
 
-##### Users ####
-class Tag(JSONModel):
-	transfer = ('name', 'count', 'user_id')
+##### Tags #####
+class TagSynonym(JSONModel):
+	transfer = ('from_tag', 'to_tag', 'applied_count')
 
+	def _extend(self, json, site):
+		self.creation_date = datetime.date.fromtimestamp(json.creation_date)
+		self.last_applied_date = datetime.date.fromtimestamp(json.last_applied_date)
+	
+	def __repr__(self):
+		return "<TagSynonym '%s'->'%s'>" % (self.from_tag, self.to_tag)
+
+class TagWiki(JSONModel):
+	transfer = ('tag_name')
+
+	def _extend(self, json, site):
+		self.body = json.wiki_body
+		self.excerpt = json.wiki_excerpt
+		self.body_last_edit_date = datetime.date.fromtimestamp(json.body_last_edit_date)
+		self.excerpt_last_edit_date = datetime.date.fromtimestamp(json.excerpt_last_edit_date)
+
+		body_editor = dict(json.last_body_editor)
+		body_editor['id'] = body_editor['user_id']
+		del body_editor['user_id']
+		self.last_body_editor = User.partial(lambda s: s.site.user(self.id), site, body_editor)
+
+		excerpt_editor = dict(json.last_excerpt_editor)
+		excerpt_editor['id'] = excerpt_editor['user_id']
+		del excerpt_editor['user_id']
+		self.last_excerpt_editor = User.partial(lambda s: s.site.user(self.id), site, excerpt_editor)
+
+class Period(Enumeration):
+	AllTime, Month = 'all-time', 'month'
+
+class TopUser(JSONModel):
+	transfer = ('score', 'post_count')
+	
+	def _extend(self, json, site):
+		user_dict = dict(json.user)
+		user_dict['id'] = user_dict['user_id']
+		del user_dict['user_id']
+		self.user = User.partial(lambda self: self.site.user(self.id), site, user_dict)
+	
+	def __repr__(self):
+		return "<TopUser '%s' (score %d)>" % (self.user.display_name, self.score)
+
+class Tag(JSONModel):
+	transfer = ('name', 'count', 'fulfills_required')
+	# Hack so that Site.vectorise() works correctly
+	id = property(lambda self: self.name)
+
+	def _extend(self, json, site):
+		self.synonyms = StackExchangeLazySequence(TagSynonym, None, site, 'tags/%s/synonyms' % self.name, self._up('synonyms'), 'tag_synonyms')
+		self.wiki = StackExchangeLazyObject(TagWiki, site, 'tags/%s/wikis' % self.name, self._up('wiki'), 'tag_wikis')
+	
+	def top_askers(self, period, **kw):
+		return self.site.build('tags/%s/top-askers/%s' % (self.name, period), TopUser, 'top_users', kw)
+
+	def top_answerers(self, period, **kw):
+		return self.site.build('tags/%s/top-answerers/%s' % (self.name, period), TopUser, 'top_users', kw)
+
+##### Users ####
 class BadgeType(Enumeration):
 	"""Describes the rank or type of a badge: one of Bronze, Silver or Gold."""
-
 	Bronze, Silver, Gold = range(3)
 
 class Badge(JSONModel):
@@ -171,6 +255,8 @@ class Badge(JSONModel):
 	
 	def __str__(self):
 		return self.name
+	def __repr__(self):
+		return '<Badge \'%s\' @ %x>' % (self.name, id(self))
 
 class RepChange(JSONModel):
 	"""Describes an event which causes a change in reputation."""
@@ -181,28 +267,64 @@ class RepChange(JSONModel):
 		self.score = self.positive_rep - self.negative_rep
 
 ## Timeline ##
-class TimelineEvent(JSONModel):
-	transfer = ('user_id', 'post_id', 'comment_id', 'action', 'description', 'detail')
-	def _extend(self, json, site):
-		self.timeline_type = TimelineEventType.from_string(json.timeline_type)
-		self.post_type = PostType.from_string(json.post_type)
-		self.creation_date = datetime.date.fromtimestamp(json.creation_date)
-	
 class TimelineEventType(Enumeration):
 	"""Denotes the type of a timeline event."""
 	_map = {'askoranswered': 'AskOrAnswered'}
-	Comment, AskOrAnswered, Badge, Revision, Accepted = range(5)
+
+	Comment = 'comment'
+	AskOrAnswered = 'askoranswered'
+	Badge = 'badge'
+	Revision = 'revision'
+	Accepted = 'accepted'
+
+class TimelineEvent(JSONModel):
+	transfer = ('user_id', 'post_id', 'comment_id', 'action', 'description', 'detail', 'comment_id')
+	_post_related = (TimelineEventType.AskOrAnswered, TimelineEventType.Revision, TimelineEventType.Comment)
+
+	def _extend(self, json, site):
+		self.timeline_type = TimelineEventType.from_string(json.timeline_type)
+		
+		if self.timeline_type in self._post_related:
+			self.post_type = PostType.from_string(json.post_type)
+			self.creation_date = datetime.date.fromtimestamp(json.creation_date)
+	
+	def _get_post(self):
+		if self.timeline_type in self._post_related:
+			if self.post_type == PostType.Question:
+				return self.site.question(self.post_id)
+			else:
+				return self.site.answer(self.post_id)
+		else:
+			return None
+
+	def _get_comment(self):
+		if self.timeline_type == TimelineEventType.Comment:
+			return self.site.comment(self.comment_id)
+		else:
+			return None
+	
+	def _get_badge(self):
+		if self.timeline_type == TimelineEventType.Badge:
+			return self.site.badge(name=self.description)
+		else:
+			return None
+
+	post = property(_get_post)
+	comment = property(_get_comment)
+	badge = property(_get_badge)
+	
 ##############
 
 class PostType(Enumeration):
 	"""Denotes the type of a post: a question or an answer."""
-
-	Question, Answer = range(2)
+	Question, Answer = 'question', 'answer'
 
 class UserType(Enumeration):
 	"""Denotes the status of a user on a site: whether it is Anonymous, Unregistered, Registered or a Moderator."""
-
-	Anonymous, Unregistered, Registered, Moderator = range(4)
+	Anonymous = 'anonymous'
+	Registered = 'registered'
+	Unregistered = 'unregistered'
+	Moderator = 'moderator'
 
 class FormattedReputation(int):
 	def format(rep):
@@ -219,6 +341,12 @@ class FormattedReputation(int):
 		else:
 			return '%.1fk' % (rep / 1000.0)
 
+class TopTag(JSONModel):
+	transfer = ('tag_name', 'question_score', 'question_count', 'answer_score', 'answer_count')
+
+	def __repr__(self):
+		return "<TopTag '%s' Q:%d A:%d>" % (self.tag_name, self.question_score, self.answer_score)
+
 class User(JSONModel):
 	"""Describes a user on a StackExchange site."""
 
@@ -226,21 +354,30 @@ class User(JSONModel):
 		'view_count', 'up_vote_count', 'down_vote_count', 'association_id')
 	def _extend(self, json, site):
 		self.id = json.user_id
-		self.user_type = Enumeration.from_string(json.user_type, UserType)
+		self.type = Enumeration.from_string(json.user_type, UserType)
 		self.creation_date = datetime.date.fromtimestamp(json.creation_date)
 		self.last_access_date = datetime.date.fromtimestamp(json.last_access_date)
 		self.reputation = FormattedReputation(json.reputation)
 
 		self.questions = StackExchangeLazySequence(Question, json.question_count, site, json.user_questions_url, self._up('questions'))
+		self.no_answers_questions = StackExchangeLazySequence(Question, None, site, 'users/%d/questions/no-answers' % self.id, self._up('no_answers_questions'), 'questions')
+		self.unanswered_questions = StackExchangeLazySequence(Question, None, site, 'users/%d/questions/unanswered' % self.id, self._up('unanswered_questions'), 'questions')
+		self.unaccepted_questions = StackExchangeLazySequence(Question, None, site, 'users/%d/questions/unaccepted' % self.id, self._up('unaccepted_questions'), 'questions')
+		self.favorites = StackExchangeLazySequence(Question, None, site, json.user_favorites_url, self._up('favorites'), 'questions')
+
 		self.answers = StackExchangeLazySequence(Answer, json.answer_count, site, json.user_answers_url, self._up('answers'))
 		# Grr, American spellings. Using them for consistency with official API.
-		self.favorites = StackExchangeLazySequence(Question, None, site, json.user_favorites_url, self._up('favorites'), 'questions')
 		self.tags = StackExchangeLazySequence(Tag, None, site, json.user_tags_url, self._up('tags'))
 		self.badges = StackExchangeLazySequence(Badge, None, site, json.user_badges_url, self._up('badges'))
 		self.timeline = StackExchangeLazySequence(TimelineEvent, None, site, json.user_timeline_url, self._up('timeline'), 'user_timelines')
+		self.reputation_detail = StackExchangeLazySequence(RepChange, None, site, json.user_reputation_url, self._up('reputation_detail'))
+
 		self.mentioned = StackExchangeLazySequence(Comment, None, site, json.user_mentioned_url, self._up('mentioned'), 'comments')
 		self.comments = StackExchangeLazySequence(Comment, None, site, json.user_comments_url, self._up('comments'))
-		self.reputation_detail = StackExchangeLazySequence(RepChange, None, site, json.user_reputation_url, self._up('reputation_detail'))
+		self.mentioned = StackExchangeLazySequence(Comment, None, site, 'users/%d/mentioned' % self.id, self._up('mentioned'))
+
+		self.top_answer_tags = StackExchangeLazySequence(TopTag, None, site, 'users/%d/top-answer-tags' % self.id, self._up('top_answer_tags'), 'top_tags')
+		self.top_question_tags = StackExchangeLazySequence(TopTag, None, site, 'users/%d/top-question-tags' % self.id, self._up('top_question_tags'), 'top_tags')
 
 		self.vote_counts = (self.up_vote_count, self.down_vote_count)
 
@@ -255,14 +392,102 @@ class User(JSONModel):
 		}
 		self.gold_badges, self.silver_badges, self.bronze_badges = self.badge_counts_t
 		self.badge_total = reduce(operator.add, self.badge_counts_t)
+		self.is_moderator = self.type == UserType.Moderator
 		
 		self.url = 'http://' + self.site.root_domain + '/users/' + str(self.id)
 	
+	def has_privelege(self, privelege):
+		return self.reputation >= privelege.reputation
+	
+	def _get_real_tag(self, tag):
+		return tag.name if isinstance(tag, Tag) else tag
+
+	def top_answers_in_tag(self, tag, **kw):
+		return self.site.build('users/%d/tags/%s/top-answers' % (self.id, self._get_real_tag(tag)), Answer, 'answers', kw)
+	
+	def top_questions_in_tag(self, tag, **kw):
+		return self.site.build('users/%d/tags/%s/top-questions' % (self.id, self._get_real_tag(tag)), Question, 'questions', kw)
+	
+	def comments_to(self, user, **kw):
+		uid = user.id if isinstance(user, User) else user
+		return self.site.build('users/%d/comments/%d' % (self.id, uid), Comment, 'comments' ,kw)
+	
 	def __unicode__(self):
 		return 'User %d [%s]' % (self.id, self.display_name)
 	def __str__(self):
 		return str(unicode(self))
+	def __repr__(self):
+		return "<User '%s' (%d) @ %x>" % (self.display_name, self.id, id(self))
 
+class Privelege(JSONModel):
+	transfer = ('short_description', 'description', 'reputation')
+
+
+class QuestionsQuery(object):
+	def __init__(self, site):
+		self.site = site
+
+	def check(self, kw):
+		if 'answers' not in kw:
+			kw['answers'] = 'true'
+		if self.site.include_body:
+			kw['body'] = 'true'
+		if self.site.include_comments:
+			kw['comments'] = 'true'
+	
+	def __call__(self, ids=None, user_id=None, **kw):
+		self.check(kw)
+		
+		# Compatibility hack, as user_id= was in versions below v1.1
+		if ids is None and user_id is not None:
+			return self.by_user(user_id, **kw)
+		elif ids is None and user_id is None:
+			return self.site.build('questions', Question, 'questions', kw)
+		else:
+			return self.site._get(Question, ids, 'questions', kw)
+	
+	def linked_to(self, qn, **kw):
+		self.check(kw)
+		url = 'questions/%s/linked' % self.site.vectorise(qn, Question)
+		return self.site.build(url, Question, 'questions', kw)
+
+	def related_to(self, qn, **kw):
+		self.check(kw)
+		url = 'questions/%s/related' % self.site.vectorise(qn, Question)
+		return self.site.build(url, Question, 'questions', kw)
+	
+	def by_user(self, usr, **kw):
+		self.check(kw)
+		kw['user_id'] = usr
+		return self.site._user_prop('questions', Question, 'questions', kw)
+	
+	def unanswered(self, by=None, **kw):
+		self.check(kw)
+		
+		if by is None:
+			return self.site.build('questions/unanswered', Question, 'questions', kw)
+		else:
+			kw['user_id'] = by
+			return self.site._user_prop('questions/unanswered', Question, 'questions', kw)
+	
+	def no_answers(self, by=None, **kw):
+		self.check(kw)
+
+		if by is None:
+			return self.site.build('questions/no-answers', Question, 'questions', kw)
+		else:
+			kw['user_id'] = by
+			return self.site._user_prop('questions/no-answers', Question, 'questions', kw)
+	
+	def unaccepted(self, by, **kw):
+		self.check(kw)
+		kw['user_id'] = by
+		return self.site._user_prop('questions/unaccepted', Questions, 'questions', kw)
+	
+	def favorited_by(self, by, **kw):
+		self.check(kw)
+		kw['user_id'] = by
+		return self.site._user_prop('favorites', Question, 'questions', kw)
 
 class Site(object):
 	"""Stores information and provides methods to access data on a StackExchange site. This class is the 'root' of the API - all data is accessed
@@ -271,9 +496,8 @@ through here."""
 	def __init__(self, domain, app_key=None):
 		self.domain = domain
 		self.app_key = app_key
-		self.api_version = '1.0'
+		self.api_version = '1.1'
 
-		self.use_gzip = True
 		self.impose_throttling = False
 		self.throttle_stop = True
 
@@ -291,11 +515,13 @@ through here."""
 	
 	def _kw_to_str(self, ob):
 		try:
-			if not isinstance(ob, str):
+			if isinstance(ob, datetime.datetime):
+				return str(time.mktime(ob.timetuple()))
+			elif isinstance(ob, str):
+				return ob
+			else:
 				i = iter(ob)
 				return ';'.join(i)
-			else:
-				return ob
 		except TypeError:
 			return str(ob).lower()
 
@@ -308,7 +534,7 @@ through here."""
 		if self.app_key != None:
 			new_params['app_key'] = self.app_key
 
-		request_properties = dict([(x, getattr(self, x)) for x in ('use_gzip', 'impose_throttling', 'throttle_stop')])
+		request_properties = dict([(x, getattr(self, x)) for x in ('impose_throttling', 'throttle_stop')])
 		request_mgr = WebRequestManager(**request_properties)
 
 		json, info = request_mgr.json_request(url, new_params)
@@ -323,19 +549,17 @@ through here."""
 		if prop not in kw:
 			raise LookupError('No user ID provided.')
 		else:
-			tid = kw[prop]
+			tid = self.vectorise(kw[prop], User)
 			del kw[prop]
 
-			return self.build('users/%d/%s' % (tid, qs), typ, coll, kw)
+			return self.build('users/%s/%s' % (tid, qs), typ, coll, kw)
 
 	def be_inclusive(self):
 		"""Include the body and comments of a post, where appropriate, by default."""
-
 		self.include_body, self.include_comments = True, True
 
 	def build(self, url, typ, collection, kw={}):
 		"""Builds a StackExchangeResultset object from the given URL and type."""
-
 		if 'body' not in kw:
 			kw['body'] = str(self.include_body).lower()
 		if 'comments' not in kw:
@@ -346,32 +570,50 @@ through here."""
 		
 	def build_from_snippet(self, json, typ):
 		return StackExchangeResultSet([typ(x, self) for x in json])
-	
+
+	def vectorise(self, lst, or_of_type=None):
+		# Ensure we're always dealing with an iterable
+		allowed_types = or_of_type
+		if allowed_types is not None and not hasattr(allowed_types, '__iter__'):
+			allowed_types = (allowed_types, )
+
+		if hasattr(lst, '__iter__'):
+			return ';'.join([str(x) for x in lst])
+		elif allowed_types is not None and [isinstance(lst, type) for type in allowed_types] and hasattr(lst, 'id'):
+			return str(lst.id)
+		else:
+			return str(lst)
+
 	def _get(self, typ, ids, coll, kw):
-		root = self.URL_Roots[typ] % ';'.join([str(x) for x in ids])
+		root = self.URL_Roots[typ] % self.vectorise(ids)
 		return self.build(root, typ, coll, kw)
 
+
 	def user(self, nid, **kw):
 		"""Retrieves an object representing the user with the ID `nid`."""
-
 		u, = self.users((nid,), **kw)
 		return u
 	
 	def users(self, ids, **kw):
 		"""Retrieves a list of the users with the IDs specified in the `ids' parameter."""
 		return self._get(User, ids, 'users', kw)
+	
+	def moderators(self, **kw):
+		"""Retrieves a list of the moderators on the site."""
+		return self.build('users/moderators', User, 'users', kw)
 
 	def answer(self, nid, **kw):
 		"""Retrieves an object describing the answer with the ID `nid`."""
-
 		a, = self.answers((nid,), **kw)
 		return a
 	
 	def answers(self, ids=None, **kw):
 		"""Retrieves a set of the answers with the IDs specified in the 'ids' parameter, or by the
 		user_id specified."""
-		if ids == None:
+		if ids is None and 'user_id' in kw:
 			return self._user_prop('answers', Answer, 'answers', kw)
+		elif ids is None:
+			return self.build('answers', Answer, 'answers', kw)
 		else:
 			return self._get(Answer, ids, 'answers', kw)
 
@@ -379,13 +621,17 @@ through here."""
 		"""Retrieves an object representing a comment with the ID `nid`."""
 		c, = self.comments((nid,), **kw)
 		return c
-	
-	def comments(self, ids=None, **kw):
-		"""Retrieves a set of the comments with the IDs specified in the 'ids' parameter."""
-		if ids == None:
-			return self._user_prop('comments', Comment, 'comments', kw)
+
+	def comments(self, ids=None, posts=None, **kw):
+		"""Returns all the comments on the site."""
+		if ids is None:
+			if posts is None:
+				return self.build('comments', Comment, 'comments', kw)
+			else:
+				url = 'posts/%s/comments' % self.vectorise(posts, (Question, Answer))
+				return self.build(url, Comment, 'comments', kw)
 		else:
-			return self._get(Comment, ids, 'comments', kw)
+			return self.build('comments/%s' % self.vectorise(ids), Comment, 'comments', kw)
 	
 	def question(self, nid, **kw):
 		"""Retrieves an object representing a question with the ID `nid`. Note that an answer ID can not be specified -
@@ -393,14 +639,7 @@ unlike on the actual site, you will receive an error rather than a redirect to t
 		q, = self.questions((nid,), **kw)
 		return q
 	
-	def questions(self, ids=None, **kw):
-		"""Retrieves a set of the comments with the IDs specified in the 'ids' parameter."""
-		if 'answers' not in kw:
-			kw['answers'] = 'true'
-		if ids == None:
-			return self._user_prop('questions', Question, 'questions', kw)
-		else:
-			return self._get(Question, ids, 'questions', kw)
+	questions = property(lambda s: QuestionsQuery(s))
 	
 	def recent_questions(self, **kw):
 		"""Returns the set of the most recent questions on the site, by last activity."""
@@ -423,10 +662,22 @@ unlike on the actual site, you will receive an error rather than a redirect to t
 		else:
 			return self._get(Badge, ids, 'users', kw)
 
-	def badge(self, nid, **kw):
-		"""Returns an object representing the badge with the ID 'nid'."""
-		b, = self.badges((nid,), kw)
-		return b
+	def badge(self, nid, name=None, **kw):
+		"""Returns an object representing the badge with the ID 'nid', or with the name passed in as name=."""
+		if name is None:
+			b, = self.badges((nid,), kw)
+			return b
+		else:
+			# We seem to need to get all badges and find it by name. Sigh.
+			all_badges = self.badges()
+			for badge in all_badges:
+				if badge.name == name:
+					return badge
+			return None
+	
+	def priveleges(self):
+		"""Returns all the priveleges a user can have on the site."""
+		return self.build('priveleges', Privelege, 'priveleges', kw)
 	
 	def all_tag_badges(self, **kw):
 		"""Returns the set of all the tag-based badges: those which are awarded for performance on a specific tag."""
@@ -449,6 +700,27 @@ unlike on the actual site, you will receive an error rather than a redirect to t
 	def search(self, **kw):
 		return self.build('search', Question, 'questions', kw)
 	
+	def similar(self, title, tagged=None, nottagged=None, **kw):
+		if 'answers' not in kw:
+			kw['answers'] = True
+		if tagged is not None:
+			kw['tagged'] = self.vectorise(tagged, Tag)
+		if nottagged is not None:
+			kw['nottagged'] = self.vectorise(nottagged, Tag)
+
+		kw['title'] = title
+		return self.build('similar', Question, 'questions', kw)
+
+	def tags(self, **kw):
+		return self.build('tags', Tag, 'tags', kw)
+	
+	def tag(self, tag, **kw):
+		kw['filter'] = tag
+		return self.build('tags', Tag, 'tags', kw)[0]
+	
+	def tag_synonyms(self, **kw):
+		return self.build('tags/synonyms', TagSynonym, 'tag_synonyms', kw)
+	
 	def __add__(self, other):
 		if isinstance(other, Site):
 			return CompositeSite(self, other)
